import json
import sys
import math

data = json.load(sys.stdin)

pretty_commands = {
    "id -u": "Process launch",
    'python3 -c"import testbase"': "Full Python startup",
    "bst help": "Run Buildstream",
    'find test-set/elements/a* -name "*.bst"': "Iterate filesystem",
    'find test-set/elements/a* -name "*.bst" | xargs stat -t': "Iterate filesystem, deliberately stat",
    'find test-set/elements/a* -name "*.bst" | xargs cat': "Iterate filesystem, read element files",
    'find test-set/elements/a* -name "*.bst" | xargs sha256sum': "Iterate filesystem, hash element files",
    'find test-set/elements/a* -name "*.bst" | python3 test-stat.py': "Iterate filesystem, deliberately stat (Python)",
    'find test-set/elements/a* -name "*.bst" | python3 test-read.py': "Iterate filesystem, read element files (Python)",
    'find test-set/elements/a* -name "*.bst" | python3 test-sha.py': "Iterate filesystem, hash element files (Python)",
    'find test-set/elements/a* -name "*.bst" | python3 test-parse.py': "Iterate filesystem, parse element files (Python)",
}


def fmt_time(t):
    if t < 1:
        return "{:3}ms".format(math.floor(t * 1000))
    else:
        return "{:4.2}s".format(math.floor(t * 100) / 100)

for cmd in data["results"]:
    mean = cmd["mean"]
    user = cmd["user"]
    sys = cmd["system"]

    pretty = pretty_commands.get(cmd["command"], cmd["command"])

    print("{:50}: {} ({} user, {} system)".format(
          pretty, fmt_time(mean), fmt_time(user), fmt_time(sys)))
